@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.40 2001/08/26 15:06:25 bazsi Exp $
+ * $Id: affile.c,v 1.41 2001/10/20 13:03:59 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -61,7 +61,7 @@ static int do_open_file(struct ol_string *name, int flags,
 		return 0;
 	}
 
-	*fd = open(name->data, flags, mode);
+	*fd = open(name->data, flags, mode != -1 ? mode : 0600);
 	if (create_dirs && *fd == -1 && errno == ENOENT) {
 		/* directory does not exist */
 		char *p = name->data + 1;
@@ -75,7 +75,7 @@ static int do_open_file(struct ol_string *name, int flags,
 					return 0;
 			}
 			else if (errno == ENOENT) {
-				if (mkdir(name->data, dir_mode) == -1)
+				if (mkdir(name->data, dir_mode != -1 ? dir_mode : 0700) == -1)
 					return 0;
 				if (dir_uid != -1 || dir_gid != -1)
 					chown(name->data, dir_uid, dir_gid);
@@ -114,7 +114,7 @@ static int do_init_affile_source(struct log_handler *c, struct syslog_config *cf
   		flags = O_RDWR | O_NOCTTY | O_NONBLOCK;
   	else
 	  	flags = O_RDONLY | O_NOCTTY | O_NONBLOCK;
-	if (do_open_file(self->name, flags, -1, -1, 0, 0, 0, 0, 0, &fd)) {
+	if (do_open_file(self->name, flags, -1, -1, -1, -1, -1, -1, 0, &fd)) {
 		struct resource_node *res;
 
 		lseek(fd, 0, SEEK_END);
