@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afinet.c,v 1.12 2001/07/08 17:04:21 bazsi Exp $
+ * $Id: afinet.c,v 1.13 2001/10/19 14:19:15 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -451,6 +451,12 @@ static int do_init_afinet_dest(struct log_handler *c,
 		return ST_OK | ST_GOON;
 	}
 	else {
+		if (errno == ECONNREFUSED) {
+			io_callout(self->cfg->backend, 
+				   self->cfg->time_reopen, 
+				   make_driver_reinit(&self->super.super.super, self->cfg));
+			return ST_OK | ST_GOON;
+		}
 		werror("Error creating AF_INET socket (%z)\n", strerror(errno));
 	}
 	return ST_FAIL | ST_QUIT;
