@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afunix.c,v 1.18 2001/07/08 17:04:21 bazsi Exp $
+ * $Id: afunix.c,v 1.19 2001/10/19 14:19:15 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -192,7 +192,7 @@ int do_init_afunix_source(struct log_handler *c,
 		struct ol_string *persistent_name;
 		struct persistent_info *p_info;
 
-		persistent_name = c_format("afunix_%S", unix_addr->path);
+		persistent_name = c_format("afunix_stream_%S", unix_addr->path);
 		p_info = find_persistent_info(persistent, persistent_name->length, persistent_name->data);
 		ol_string_free(persistent_name);
 
